Module: VagrantPlugins::Parallels
- Defined in:
- lib/vagrant-parallels.rb,
lib/vagrant-parallels/cap.rb,
lib/vagrant-parallels/action.rb,
lib/vagrant-parallels/config.rb,
lib/vagrant-parallels/errors.rb,
lib/vagrant-parallels/plugin.rb,
lib/vagrant-parallels/version.rb,
lib/vagrant-parallels/provider.rb,
lib/vagrant-parallels/action/boot.rb,
lib/vagrant-parallels/driver/base.rb,
lib/vagrant-parallels/driver/meta.rb,
lib/vagrant-parallels/util/common.rb,
lib/vagrant-parallels/driver/pd_11.rb,
lib/vagrant-parallels/driver/pd_12.rb,
lib/vagrant-parallels/action/export.rb,
lib/vagrant-parallels/action/import.rb,
lib/vagrant-parallels/action/resume.rb,
lib/vagrant-parallels/synced_folder.rb,
lib/vagrant-parallels/action/destroy.rb,
lib/vagrant-parallels/action/network.rb,
lib/vagrant-parallels/action/package.rb,
lib/vagrant-parallels/action/suspend.rb,
lib/vagrant-parallels/action/set_name.rb,
lib/vagrant-parallels/action/customize.rb,
lib/vagrant-parallels/cap/mount_options.rb,
lib/vagrant-parallels/action/forced_halt.rb,
lib/vagrant-parallels/action/box_register.rb,
lib/vagrant-parallels/synced_folder_macvm.rb,
lib/vagrant-parallels/action/forward_ports.rb,
lib/vagrant-parallels/action/sane_defaults.rb,
lib/vagrant-parallels/action/snapshot_save.rb,
lib/vagrant-parallels/model/forwarded_port.rb,
lib/vagrant-parallels/action/box_unregister.rb,
lib/vagrant-parallels/action/snapshot_delete.rb,
lib/vagrant-parallels/action/snapshot_restore.rb,
lib/vagrant-parallels/util/unix_mount_helpers.rb,
lib/vagrant-parallels/action/handle_guest_tools.rb,
lib/vagrant-parallels/action/package_vagrantfile.rb,
lib/vagrant-parallels/action/setup_package_files.rb,
lib/vagrant-parallels/action/clear_shared_folders.rb,
lib/vagrant-parallels/action/package_config_files.rb,
lib/vagrant-parallels/action/prepare_nfs_settings.rb,
lib/vagrant-parallels/action/clear_forwarded_ports.rb,
lib/vagrant-parallels/action/prepare_nfs_valid_ids.rb,
lib/vagrant-parallels/util/compile_forwarded_ports.rb,
lib/vagrant-parallels/action/check_shared_interface.rb,
lib/vagrant-parallels/action/prepare_clone_snapshot.rb,
lib/vagrant-parallels/action/clear_network_interfaces.rb,
lib/vagrant-parallels/guest_cap/linux/install_parallels_tools.rb,
lib/vagrant-parallels/action/destroy_unused_network_interfaces.rb,
lib/vagrant-parallels/guest_cap/darwin/install_parallels_tools.rb,
lib/vagrant-parallels/guest_cap/windows/install_parallels_tools.rb,
lib/vagrant-parallels/guest_cap/linux/mount_parallels_shared_folder.rb,
lib/vagrant-parallels/action/prepare_forwarded_port_collision_params.rb,
lib/vagrant-parallels/guest_cap/darwin/mount_parallels_shared_folder.rb
Defined Under Namespace
Modules: Action, Cap, Driver, Errors, GuestDarwinCap, GuestLinuxCap, GuestWindowsCap, Model, SyncedFolderCap, Util Classes: Config, Plugin, Provider, SyncedFolder, SyncedFolderMacVM
Constant Summary collapse
- VERSION =
'2.4.9'
Class Method Summary collapse
-
.source_root ⇒ Pathname
This returns the path to the source of this plugin.
Class Method Details
.source_root ⇒ Pathname
This returns the path to the source of this plugin.
15 16 17 |
# File 'lib/vagrant-parallels.rb', line 15 def self.source_root @source_root ||= Pathname.new(File.('../../', __FILE__)) end |