Class: VagrantPlugins::Parallels::Model::ForwardedPort

Inherits:
Object
  • Object
show all
Defined in:
lib/vagrant-parallels/model/forwarded_port.rb

Overview

Represents a single forwarded port for Parallels Desktop. This has various helpers and defaults for a forwarded port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, host_port, guest_port, host_ip, guest_ip, **options) ⇒ ForwardedPort

Returns a new instance of ForwardedPort.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 42

def initialize(id, host_port, guest_port, host_ip, guest_ip, **options)
  @id         = id
  @guest_port = guest_port
  @guest_ip   = guest_ip
  @host_port  = host_port
  @host_ip    = host_ip

  options ||= {}
  @auto_correct = false
  @auto_correct = options[:auto_correct] if options.key?(:auto_correct)
  @protocol = options[:protocol] || 'tcp'
end

Instance Attribute Details

#auto_correctBoolean (readonly)

If true, the forwarded port should be auto-corrected.

Returns:

  • (Boolean)


10
11
12
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 10

def auto_correct
  @auto_correct
end

#guest_ipString (readonly)

The ip of the guest to be used for the port.

Returns:

  • (String)


35
36
37
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 35

def guest_ip
  @guest_ip
end

#guest_portInteger (readonly)

The port on the guest to be exposed on the host.

Returns:

  • (Integer)


25
26
27
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 25

def guest_port
  @guest_port
end

#host_ipString (readonly)

The ip of the host used to access the port.

Returns:

  • (String)


40
41
42
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 40

def host_ip
  @host_ip
end

#host_portInteger (readonly)

The port on the host used to access the port on the guest.

Returns:

  • (Integer)


30
31
32
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 30

def host_port
  @host_port
end

#idString (readonly)

The unique ID for the forwarded port.

Returns:

  • (String)


15
16
17
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 15

def id
  @id
end

#protocolString (readonly)

The protocol to forward.

Returns:

  • (String)


20
21
22
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 20

def protocol
  @protocol
end

Instance Method Details

#correct_host_port(new_port) ⇒ Object

This corrects the host port and changes it to the given new port.

Parameters:

  • new_port (Integer)

    The new port



58
59
60
# File 'lib/vagrant-parallels/model/forwarded_port.rb', line 58

def correct_host_port(new_port)
  @host_port = new_port
end