Class: VagrantPlugins::Parallels::Plugin
- Inherits:
-
Object
- Object
- VagrantPlugins::Parallels::Plugin
- Defined in:
- lib/vagrant-parallels/plugin.rb
Class Method Summary collapse
-
.setup_i18n ⇒ Object
This initializes the internationalization strings.
-
.setup_logging ⇒ Object
This sets up our log level to be whatever VAGRANT_LOG is.
Class Method Details
.setup_i18n ⇒ Object
This initializes the internationalization strings.
132 133 134 135 |
# File 'lib/vagrant-parallels/plugin.rb', line 132 def self.setup_i18n I18n.load_path << File.('locales/en.yml', Parallels.source_root) I18n.reload! end |
.setup_logging ⇒ Object
This sets up our log level to be whatever VAGRANT_LOG is.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/vagrant-parallels/plugin.rb', line 138 def self.setup_logging require 'log4r' level = nil begin level = Log4r.const_get(ENV['VAGRANT_LOG'].upcase) rescue NameError # This means that the logging constant wasn't found, # which is fine. We just keep `level` as `nil`. But # we tell the user. level = nil end # Some constants, such as "true" resolve to booleans, so the # above error checking doesn't catch it. This will check to make # sure that the log level is an integer, as Log4r requires. level = nil if !level.is_a?(Integer) # Set the logging level on all "vagrant" namespaced # logs as long as we have a valid level. if level logger = Log4r::Logger.new('vagrant_parallels') logger.outputters = Log4r::Outputter.stderr logger.level = level logger = nil end end |