Module: VagrantPlugins::Parallels::Driver
- Defined in:
- lib/vagrant-parallels/plugin.rb,
lib/vagrant-parallels/driver/base.rb,
lib/vagrant-parallels/driver/meta.rb,
lib/vagrant-parallels/driver/pd_11.rb,
lib/vagrant-parallels/driver/pd_12.rb
Overview
Drop some autoloads in here to optimize the performance of loading our drivers only when they are needed.